@@ -1,4 +1,4 @@
-from .trimap import TRIMAP
+from .trimap_ import TRIMAP
 
 import pkg_resources
 __version__ = pkg_resources.get_distribution('trimap').version
